@@ -1,12 +1,14 @@
-/***********************************************************
- * RHmm version 1.0.3                                      *
- *                                                         *
- *                                                         *
- * Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> *
- *                                                         *
- * Date: 2008/06/26                                        *
- *                                                         *
- ***********************************************************/
+/**************************************************************
+ *** RHmm version 1.2.0                                      
+ ***                                                         
+ *** File: MultivariateNormalUtil.cpp 
+ ***                                                         
+ *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
+ ***                                                         
+ *** Date: 2008/11/29                                        
+ ***                                                         
+ **************************************************************/
+
 #include "MultivariateNormalUtil.h"
 
 void SymetricInverseAndDet	(	cOTMatrix&	theMat,
@@ -34,7 +36,7 @@ double			myAux,
 				myRapport		;
 
 uint myDimObs = theMu.mSize ;	
-	myRapport = pow(SQRT_TWO_PI*sqrt(theDet), (int)myDimObs) ;
+	myRapport = pow(SQRT_TWO_PI, (int)myDimObs)*sqrt(theDet) ;
 
 uint myT = thex.mSize / myDimObs ;
 
