@@ -1,18 +1,20 @@
-/***********************************************************
- * RHmm version 1.0.3                                      *
- *                                                         *
- *                                                         *
- * Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> *
- *                                                         *
- * Date: 2008/06/26                                        *
- *                                                         *
- ***********************************************************/
+/**************************************************************
+ *** RHmm version 1.2.0                                      
+ ***                                                         
+ *** File: MultivariateNormalUtil.h 
+ ***                                                         
+ *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
+ ***                                                         
+ *** Date: 2008/11/29                                        
+ ***                                                         
+ **************************************************************/
+
 #ifndef _MULTIVARIATENORMALUTIL_H_
 #define _MULTIVARIATENORMALUTIL_H_
 #include "OTMathUtil.h"
 
 #ifndef _RDLL_
-	#include "R_Equivalents.h"
+	#include "REquivalents.h"
 #else
 	#include <stdio.h>
 	#include <stdlib.h>
