@@ -1,16 +1,18 @@
-/***********************************************************
- * RHmm version 1.0.3                                      *
- *                                                         *
- *                                                         *
- * Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> *
- *                                                         *
- * Date: 2008/06/26                                        *
- *                                                         *
- ***********************************************************/
+/**************************************************************
+ *** RHmm version 1.2.0                                      
+ ***                                                         
+ *** File: cMultivariateNormal.h 
+ ***                                                         
+ *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
+ ***                                                         
+ *** Date: 2008/11/29                                        
+ ***                                                         
+ **************************************************************/
+
 #ifndef _CMULTIVARIATENORMAL_H_
 #define _CMULTIVARIATENORMAL_H_
 #include "cDistribution.h"
-#include "samplesUtil.h"
+#include "SamplesUtil.h"
 
 class cMultivariateNormal : public cDistribution
 {	private :
